#
# spec file for package vorta
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1500
# Build only one time
%define pythons %{primary_python}
%else
# Build only with python 3.11
%{?sle15_python_module_pythons}
%endif
Name:           vorta
Version:        0.10.3
Release:        1.2
Summary:        Desktop Backup Client based on BorgBackup
License:        Apache-2.0 AND GPL-3.0-only AND OFL-1.1
Group:          Productivity/Archiving/Backup
URL:            https://github.com/borgbase/vorta
Source:         https://github.com/borgbase/%{name}/archive/v%{version}.tar.gz
Source1:        vorta.desktop
# PATCH-FIX-OPENSUSE vorta-fix-dependencies.patch malcolmlewis@opensuse.org -- Remove dependencies that are named differently.
Patch0:         vorta-fix-dependencies.patch
BuildRequires:  %{python_module PyQt6}
BuildRequires:  %{python_module peewee}
BuildRequires:  %{python_module platformdirs}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools-git}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python-rpm-macros
BuildRequires:  update-desktop-files
Requires:       %{python_flavor}-PyQt6
Requires:       %{python_flavor}-SecretStorage
Requires:       %{python_flavor}-peewee
Requires:       %{python_flavor}-platformdirs
Requires:       %{python_flavor}-psutil
Requires:       borgbackup
BuildArch:      noarch

%description
Vorta is a backup client for Linux desktops. It integrates BorgBackup with
the desktop environment to protect data from disk failure,
ransomware and theft.

%prep
%autosetup -p1

%build
export LANG=en_US.UTF-8
%python_build

%install
export LANG=en_US.UTF-8
%python_install
install -d %{buildroot}%{_datadir}/icons/hicolor/256x256/apps
install -Dm644 "src/vorta/assets/icons/icon.svg" "%{buildroot}%{_datadir}/icons/hicolor/256x256/apps/vorta.svg"
install -Dm644 -t %{buildroot}%{_datadir}/metainfo "src/vorta/assets/metadata/com.borgbase.Vorta.appdata.xml"
%suse_update_desktop_file -i vorta
%fdupes %{buildroot}%{python_sitelib}

%files
%license LICENSE.txt
%doc README.md
%{_bindir}/vorta
%{_datadir}/applications/vorta.desktop
%{_datadir}/metainfo/com.borgbase.Vorta.appdata.xml
%{_datadir}/icons/hicolor/256x256/apps/vorta.svg
%{python_sitelib}/%{name}
%{python_sitelib}/%{name}-%{version}-py%{python_bin_suffix}.egg-info

%changelog
* Fri Jan 17 2025 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Updated to version 0.10.3:
  * see https://github.com/borgbase/vorta/releases/tag/v0.10.3
- Updated to version 0.10.2:
  * see https://github.com/borgbase/vorta/releases/tag/v0.10.2
* Thu Nov 28 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Updated to version 0.10.1:
  * see https://github.com/borgbase/vorta/releases/tag/v0.10.1
- Updated to version 0.10.0:
  * see https://github.com/borgbase/vorta/releases/tag/v0.10.0
- Clean dependencies
- Refresh vorta-fix-dependencies.patch
* Fri May 24 2024 Lubos Kocman <lubos.kocman@suse.com>
- Update license to match legaldb report
  add OFL-1.1 and Apache-2.0
* Fri May 24 2024 Max Lin <mlin@suse.com>
- Fix Leap 15.6 build
  * Build with python 3.11
* Thu Jan 11 2024 malcolmlewis@opensuse.org
- Updated to version 0.9.1:
  * Profile Sidebar and New Setting Interface,
    (gh#borgbase/vorta#1809).
  * Exclude GUI, (gh#borgbase/vorta#1846).
  * Use Qt6 for the interface, (gh#borgbase/vorta#1685).
  * Integration testing with Borg and increased coverage.
- Changes from version 0.9.0:
  * 0.9 branch now uses PyQt6 under the hood.
- Rename fix-dependencies.patch to vorta-fix-dependencies.patch
  and rebase.
- Spec file tidy up.
* Wed Apr 19 2023 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Install the appdata.xml file
* Wed Apr 19 2023 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- update to 0.8.12:
  * see https://github.com/borgbase/vorta/releases/tag/v0.8.12
  * Removes a leftover dependency of paramiko
- update to 0.8.11:
  * see https://github.com/borgbase/vorta/releases/tag/v0.8.11
  * Retain sort settings in extract, diff and source views.
  * Support new Borg diff types.
  * Remove Paramiko dependency.
  * Migrate from appdirs to platformdirs.
  * Add tooltips to many settings in Misc tab.
  * Allow adding a SSH key when no repo was added yet.
- Refresh fix-dependencies.patch
* Thu Feb 16 2023 CJ <c.j@tuta.io>
- Add the missing applications menu icon
* Tue Jan 24 2023 Dirk Müller <dmueller@suse.com>
- update to 0.8.10:
  * see https://github.com/borgbase/vorta/releases/tag/v0.8.10
  * Add Borg v2 compatibility (based on beta4).
  * Improve Linux desktop tray behavior.
  * Improve check and extract commands.
  * Fix blocking issue with temp file when extracting files
* Tue Nov  8 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 0.8.9
  * Supply repository and archive name to borg in BorgListArchiveJob.
  * Add missing brackets fixing BorgListArchiveJob.
  * Add Dutch language update
  * Pin pyobjc to v8 branch
- Update to 0.8.8
  * This version adds compatibility for Borg v1.2.2 and addresses several
    smaller UI bugs.
  * Fix sorting of diff results.
  * Remove legacy tree_view (tree model) implementation.
  * Remove unset repository value from combobox when a repo is selected.
  * Replace --prefix with -a for borg v1.2.2 also.
  * Use isomtime instead of mtime from borg v1.2.2 on.
  * Add compatibility feature V122.
  * Link to report form chooser for critical errors. (#1451)
  * (real-yfprojects/profile-sidebar, real-yfprojects/master) Update
    actions/checkout to v3. (#1433)
  * Add default unset value to repo combobox. By @real-yfprojects (#1429)
  * Enhance community docs and bug reporting. By @real-yfprojects (#1419)
  * Add pull request template.
  * Add CONTRIBUTING file.
  * Create feature_request.md
  * Create bug_form.yaml
  * Create config.yml
  * Update bug_report.md
  * Log the error when parsing a file in ~/.ssh fails. (#1410)
  * Hide SSH dropdown for local repos. By @real-yfprojects (#1407)
  * Add badges to README.md. (#1406)
  * Improve tooltips in archive tab. By @real-yfprojects (#1401)
  * Run hooks on the code base.
  * Configure pre-commit hooks and configure black for tests also.
  * Create .git-blame-ignore-revs (#1395)
  * Move linting to the top in test.yml (#1391)
  * Apply automatic formatting
  * Add config files for autmatic formatting
  * Cleanup temp files. By @marco44 (#1384)
  * Add spaces after assert and enhance git py diff. By @real-yfprojects (#1385)
  * Improve the extract and diff dialog. By @real-yfprojects (#1219)
  * (real-yfprojects/sort-diff-result, sort-diff-result-2) Add icons to display
    mode combobox.
  * Add icon for folder on top button.
  * Improve extract dialog GUI.
  * Add sorting to ExtractDialog.
  * Implement extracting exactly the selected files.
  * Use new treemodel for extract dialog.
  * Keep GUI responsive while processing diff results.
  * Open DiffResultDialog as a normal dialog instead of a sheet.
  * Update diffresult.ui with new features and prettyfy it.
  * Use new treemodel for diff view.
  * Implement fresh TreeModel for TreeViews.
  * Add missing Qt dependency for tests (#1376)
  * Fix seconds and microseconds for fixed schedule and fix scheduling for the same day. (#1368)
  * Log json diff line parsing errors. By @real-yfprojects (#1369)
* Wed Jun 22 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 0.8.7
  * Deal with new archive_progress key (#1353)
  * Raise ValueError in case of unknown change type in diff json. By @real-yfprojects (#1350)
  * Fix unlink action when repo combobox is empty. By @real-yfprojects (#1342)
  * Show date of next backup. By @tal66 (#1319)
- Update to 0.8.6
  * Remove call to QTranslator.language() in get_locale. (#1316)
- Update to 0.8.5
  * Fix macOS Archive settings form sizing (#1311)
  * Fix copying the current repo to the clipboard. By @real-yfprojects (#1313)
  * Determine source files for translations dynamically. By @real-yfprojects (#1309)
  * Remove leftovers in repo selector (#1308)
  * Pause scheduling temporarily on failures. By @real-yfprojects (#1299)
  * Only schedule backup after a manual run, improve labels. @real-yfprojects (#1302)
  * Select and delete multiple archives. By @real-yfprojects (#1307)
  * Preserve last creation log per profile for scheduler. By @real-yfprojects (#1296)
  * Don't schedule if no repo is set. By @real-yfprojects (#1288)
  * Hotfix for right-click archive menu. By @real-yfprojects (#1285)
* Fri May 20 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 0.8.4
  * Major changes:
  * Improve UX and HIG-conformity. By @real-yfprojects (#1176)
  * Rewrite scheduler logic. By @real-yfprojects (#1204)
  * Other improvements:
  * Change default returncode for log. By @real-yfprojects (#1193)
  * Update next backup time label. By @real-yfprojects (#1180)
  * Support new borg compact command (#1205)
  * Change keyring label to improve UX on Gnome. By @real-yfprojects (#1181)
  * Add missing translate strings. By @delfino-nunez (#1229)
  * Fix setting a timer value too large for C++ int. (#1230)
  * Add missing translation marking. By @delfino-nunez (#1240)
  * Use accept-new for host keys. By @delfino-nunez (#1238)
  * Properly set dialog titles. By @delfino-nunez (#1246)
  * Use fnmatch for exclude patterns. By @real-yfprojects (#1253)
  * Add a button to mount full repository. By @real-yfprojects (#1257)
  * Clarify enable_background_question label. By @real-yfprojects (#1262)
  * Improve SecretStorage locking behavior. By @Aeysol (#1255)
  * Set repo stats to N/A after delete or prune. By @real-yfprojects (#1251)
  * Improve keyring logging. By @real-yfprojects (#1263)
  * Better diff selection without extra dialog. By @real-yfprojects (#1235)
  * Add support for special file types in borg diff output. By @real-yfprojects (#1265)
* Mon Feb  7 2022 Antonio Larrosa <alarrosa@suse.com>
- Update to 0.8.3
  * Distinguish different errors in case borg check failed.
    By @real-yfprojects (#1163)
  * Close SVG files after reading. By @hroncok (#1135)
  * Shows folder sizes in diff view. By @skrap (#1156)
  * Ignore encoding errors in Wifi names (darwin) (#1158)
  * Upgrade llfuse for Flatpak (#1179)
  * Bump macOS updater to Sparkle 2.0 (#1186)
  * Minor test fixes (#1150, #1147, #1146)
- Rebase patch:
  * fix-dependencies.patch
* Wed Dec 29 2021 Marcus Hann <marcus@hhra.uk>
- Update to 0.8.2
  * Refactor Borg job scheduling. By @bastiencyr
  * Remove APScheduler dependency and use QTimer directly
  * Python 3.10 compatibility
- Update to 0.8.1
  * Use native threading module in job_manager. (#1096)
  * Fix next_job timer logic. By @jayeclark (#1100)
  * Remove jobs if scheduler setting is changed. (#1105)
  * Remove jobs before deleting profile (#1107)
  * Make sure correct sources are removed (#1110)
  * Address DB Locking issues (#1109)
  * Refactor: Split up vorta/models.py (#1112)
  * Notify on failed repo checks (#1113)
- Update to 0.8.0
  * Implement multiple queues. By @bastiencyr (#1045)
  * Show backup size with excludes applied. By @freder (#961)
  * Remove APScheduler dependency, Python 3.10 support (#1086)
  * Add tooltip containing path name. By @XXXBold (#1072)
  * Increases the maximum allowed number in prune keep. By @lstrz (#1089)
  * Always handle autosave setting when saving SettingsModel. By @phihos (#1093)
* Fri Dec 10 2021 pgajdos@suse.com
- pytest-runner is deprecated
* Tue Aug 31 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.7.8:
  * Fix double call to on_user_click
  * Handle malformed .vorta-init.json on import
* Tue Jul  6 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.7.7
  * New features:
    + Import/export settings (or bootstrap with default config)
    + Add support for 'diff --json-lines'
  * Bugfixes and refinements:
    + Alert when deleting last profile
    + Put folders first in diff/extract
    + Skip sizing folders on permission error
    + Called set_progress() on wrong class
    + Fix color for eye icon when masking password
    + Refuse to add inaccessible folders, warn on inaccessible files during backup
    + Open window on left-click on Linux
    + Fix issue #940 - KeyError in get_dict_from_list
    + Correctly rename profile in dropdown
    + Fix 'list --json-lines' command when only a single result line is output
* Fri Apr 16 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.7.5
  * Bug fixes and improvements
    + With this release you can disable the system keychain and
    just keep the repo passphrase in Vorta's settings DB
    (slightly less secure).
    + Also, keyring is now picked by assigning a score. So it will
    prioritized KWallet on KDE and Secret Storage on Gnome.
    + Use json mode to list archive files. By @rblenis (#885)
    Add untranslated strings. By @samuel-w (#902)
* Sun Feb 28 2021 Dirk Müller <dmueller@suse.com>
- update to 0.7.4:
  * Fix log table sorting.
  * Improve kwallet verification.
  * Remove failing SSH key check
  * Avoid segfault when quitting
* Tue Feb 23 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.7.3
  * Possible Breaking Changes
    + This removes the profile_slug from the default archive name
    and prefix. This change only applies to new backup profiles.
    So if you use the same repo for multiple projects on the
    same hostname, be sure to check your prune prefix as well.
    The new default archive name is:
    {hostname}-{now:%%Y-%%m-%%d-%%H%%M%%S}
  * New Features
    + Add mount option override checkbox. By @samuel-w (#682)
    + Add custom options to borg create command.
    By @samuel-w (#677)
    + Add rename action. By @samuel-w and @m3nu (#864)
    + Give option to break repository lock. By @samuel-w (#863)
  * Bugfixes
    + Remove support for deprecated macOS XML wifi list. (#868)
    + Catch more possible SSH key parsing errors. (#789)
    + Improve cancelling Borg process (#786)
    + Add QTimer to ensure background jobs are scheduled correctly.
    (#780)
    + Fix corrupted archive table list during refresh if sorting
    is enabled. By @rblenis (#784)
- Rebase patch:
  * fix-dependencies.patch
* Tue Feb  9 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.7.2
  * Renable buttons on cancel. By @samuel-w (#772)
  * Allow pasting files/folders from file manager, set model
    defaults (#759)
  * Add option to disable exit dialog. By @samuel-w (#681)
  * Allow only one profile with --create. By @samuel-w (#744)
  * Improved password handling and transparency. By @samuel-w
    (#550)
  * Fix file selector dialog (#764)
  * Fix label colour not changing on dark mode change.
    By @samuel-w (#757)
  * Cleanup database at exit, use write-ahead logging.
    By @samuel-w (#696)
  * Sort files in Extract dialog alphabetically. By @samuel-w
    (#741)
  * Update check message on completion. By @samuel-w (#672)
  * Give error message on unmount failure. By @samuel-w (#668)
  * Improve exception handling. By @samuel-w (#628)
  * Ensure system keychain is unlocked before using it.
    By @samuel-w (#607)
  * Create backups from command line using existing profiles.
    By @samuel-w (#556)
  * Diff: better color of added and removed text.
    By @samuel-w (#649)
  * Add KWallet support. By @samuel-w (#540)
  * Correctly sort archives by size. By @samuel-w (#729)
  * Refactoring: remove last exec_, add tests, retain archive
    deletion message. By @samuel-w (#722)
  * Refactor add and rename to not use exec_. By @samuel-w (#721)
  * Improve autostart test. By @samuel-w (#720)
  * Limit network checking to only remote repos.
    By @samuel-w (#701)
  * Re-enable SSH host key checking for all operations except
    when adding repo (#717)
  * Add valid copyright header to Johan Rade's work.
    By @sten0 (#716)
  * Display number of files and sizes in source tab.
    By @XXXBold (#617)
  * Translate category labels for log output. By @samuel-w (#683)
  * Fix crash when window is closed while thread running.
    By @samuel-w (#685)
  * Reuse existing window when bringing to front. (#674)
  * Set icon through code (#676)
  * Show dialog on copy failure. By @samuel-w (#647)
  * Get keyring at runtime. By @samuel-w (#635)
  * Save correct window size. By @samuel-w (#661)
  * Properly catch DBusException. By @samuel-w (#670)
  * Set application name (#666)
  * Set all icons to same height (#660)
  * Replace Borg version with install method in bug report (#657)
  * Reduce icon memory usage. By @samuel-w (#656)
  * Cancel Borg thread at end of test. (#648)
- Update to version 0.7.1
  * Fix crash when GUI is opened via tray icon while a backup is
    running. By @samuel-w
  * Use single tray icon for light and dark themes. By @samuel-w
  * Use naked en locale instead of en_US. Fixes #623 (#626)
  * Remove 'Backup in progress' when re-opening window (#627)
    by @samuel-w
  * Avoid formatting date and time twice. Fixes #624 (#625)
  * Handle DBusException in NetworkManagerMonitor (#636)
    by @ktosiek
  * Initialize the network status monitor lazily (#634)
    by @ktosiek
- Update to version 0.7.0
  * Proper dark style support and removal of style hacks
  * Prevent duplicate repos from being added. Fixes #473
  * New setting to store previously selected profile. Fixes #241
  * Add error message when Borg binary is missing. Fixes #333
  * Notify of errors after system tray backup run. Fixes #105
  * Linux Desktop file: fix syntax, enhance Categories,
    add a Keyword. By @sten0
  * Fix parsing "changed link" lines. By @ktosiek
  * Add paste button for source paths. By @samuel-w
  * Prevent profiles from sharing the same name. Fixes #512.
    By @samuel-w
  * Add copy button for repository URLs/paths. Fixes #409.
    By @samuel-w
  * Move socket file from state-dir to tmp-dir. Fixes #513
  * Save main window state before closing. By @Hofer-Julian
  * Parse owner changes in borg diff results. By @ktosiek
  * Fix tests for PyQt 5.15 on Linux. By @samuel-w
  * Refactor Linux autostart by @samuel-w
  * Add correct icon for notifications on Linux. By @Hofer-Julian
  * Newer macOS deploy target for detecting dark mode. Fixes #575
  * Enable multiselection on source list by @XXXBold
  * Allow selection of multiple files by @samuel-w for #593
  * Prevent running backups on metered network. By @ktosiek
  * Add autosorting for source list. By @samuel-w
  * Use dt.now everywhere. By @samuel-w
  * Improved progress updates. By @SergioRAgostinho
- Remove patch which is not needed anymore:
  * fix-qtoolbox-titles.patch
* Tue May 26 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.6.26
  * Fixes some issues when no known Wifis are available on macOS.
  * Starts with the correct window size for high-res displays on Linux.
  * Test- and linting fixes.
- Version 0.6.25 wasn't released by upstream.
* Mon May 18 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.6.24
  * Add Czech and Finnish translations.
  * Simplify startup behavior. Run in foreground by default (used
    by Flatpak and macOS). Use --daemonize to start in background.
* Thu Oct 31 2019 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.6.23
  * Move setting prune options to right place. Fixes gh#borgbase/vorta#339
  * Improvements to diff-feature.
  * Enable sorting of archive table columns.
  * Always mount with current user and read-only permissions
* Wed Oct  2 2019 Frederik Möllers <frederik@die-sinlosen.de>
- Update to version 0.6.22
  * Remove keyring dependency and refactor keyrings
  * Allow for extra borg arguments per-repo
  * Reduce memory usage by removing main window from memory when closed
  * Prevent KeyError when reading KnownNetworks on macOS
  * Expand user path in python before setting BORG_RSH
  * Catch Keyboard interrupt when running in foreground mode
  * Make autostart for Linux more stable
  * Avoid duplicate files in Extract dialog, avoid passing None to shlex when parsing extra args
  * Changes vorta's default tray icon to white on GNOME
  * Workaround for jeepney DBus-lib and asyncio event loop.
    Fixes gh#borgbase/vorta#234
  * Fall back to saving passwords in the database, when no Gnome-Keyring is installed
  * Implement QtSingleApplication
    Implements gh#borgbase/vorta#243
  * Remove non-ASCII em-dash from Manifest.in
  * Re-enable mounting of whole repo
  * Get borg version and path on startup. Link to log folder
    Implements gh#borgbase/vorta#247
  * Add helper class to manage Borg version and supported features
    Implements gh#borgbase/vorta#250
  * Correctly set environment encoding (pyinstaller issue)
    Fixes gh#borgbase/vorta#220
  * Fix default white icon behaviour for Ubuntu GNOME
  * Don't delete item from sources if item==None
  * Fix issue when Borg binary is missing
    Fixes gh#borgbase/vorta#258
  * Add date-based log rotation
    Partially fixes last part of gh#borgbase/vorta#121
  * Remove unique constraint from Archive ID
    Fixes gh#borgbase/vorta#253
  * Adress an issue with sqlite when the archive table to be migrated is very large
  * Handle OSError 6 when trying to read a socket in .ssh
  * Pre-backup command runs before repository checks
  * Implement --version
    Fixes gh#borgbase/vorta#260
  * If BORG_PASSCOMMAND is found, unset BORG_PASSPHRASE
    Fixes gh#borgbase/vorta#272
  * Raise meaningful error when Borg version found is too old
    Fixes Fixes gh#borgbase/vorta#283
  * Ignore Python processes owned by other users when finding mount points
  * Implement borg diff
  * Include more links into appdata
  * Default opt-in for enable_notifications_success
  * Rename background-option to daemonize
  * Implement close-question for DEs without system tray
  * Fix autostart icon
  * Allow is_system_tray_available to be called with running event loop
  * Add option for starting Vorta in foreground
* Mon Feb 25 2019 Antonio Larrosa <alarrosa@suse.com>
- Add fix-qtoolbox-titles.patch to fix a problem with QToolBox tab
  titles being cut at a fixed width independently of the title text
  or tab width.
* Mon Feb 25 2019 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.6.10
  * Also set tray icon according to detected theme.
    Fixes gh#borgbase/vorta#199
  * Avoid deadlock when calling subprocess.Popen().
    Fixes gh#borgbase/vorta#187
  * Remove translation functions for Borg logging messages.
    Fixes gh#borgbase/vorta#197
  * Implement autostart for Linux
  * Add French and Italian translations
  * Update compressor selection: add zlib, add zstd,8, descriptions.
    Fixes gh#borgbase/vorta#145
  * Add tooltip to "add profile" button. Fixes gh#borgbase/vorta#183
- Update to version 0.6.8
  * Implement add profile button
  * Translation Bugfixes
* Fri Feb  8 2019 Antonio Larrosa <alarrosa@suse.com>
- Set LANG to use UTF-8 and fix builds in Leap 15.1
* Thu Feb  7 2019 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.6.7
  * Separate light/dark settings for icon and theme.
    Fixes gh#borgbase/vorta#171
  * Ask for confirmation on delete (and small fixes)
    (gh#borgbase/vorta#176)
  * Show/Hide the main window in KDE when clicking on the tray icon
    (gh#borgbase/vorta#143)
  * Add debug tools for i18n UI layout checking (gh#borgbase/vorta#160)
  * Fix crash due to zombie processes (gh#borgbase/vorta#174)
  * Use ellipsis the Qt way in the archive table (gh#borgbase/vorta#169)
  * Fix Issue "Crash when cancelling "add new profile"
    gh#borgbase/vorta#168" (gh#borgbase/vorta#170)
- Update to version 0.6.6
  * Add light icons and dark stylesheet. Fixes gh#borgbase/vorta#151
    (gh#borgbase/vorta#155)
  * Implement feature to delete specific archive (gh#borgbase/vorta#164)
  * Programmatically detect theme color (for macOS) (gh#borgbase/vorta#150)
  * Add app name to tray menu and window title (gh#borgbase/vorta#153)
  * Improve archive mount feature. Fixes gh#borgbase/vorta#131. By @antlarr
    (gh#borgbase/vorta#156)
  * Translation-related improvements and German translation
    (gh#borgbase/vorta#146)
  * Skip sockets when reading private keys (gh#borgbase/vorta#147)
  * Remove leftover Sentry references. Fixes gh#borgbase/vorta#127
    (gh#borgbase/vorta#142)
  * Make the main window resizeable (gh#borgbase/vorta#130)
- Drop fix-umount.patch which was already merged upstream
* Wed Jan 23 2019 Jan Engelhardt <jengelh@inai.de>
- Generalize description.
* Thu Jan 17 2019 alarrosa@suse.com
- Use %%python3* macros to build and install
- Fix fdupes call
- Add desktop file and install application icon
* Wed Jan 16 2019 alarrosa@suse.com
- Initial release of vorta 0.6.5
